/**
    @file ft51_dio_registers.h

    @brief Digital IO Registers library

    Defines registers and bit-masks associated with Digital Input/Output.

    @version 1.0.0

**/
/*
 * ============================================================================
 * History
 * =======
 *
 * (C) Copyright 2014, Future Technology Devices International Ltd.
 * ============================================================================
 *
 * This source code ("the Software") is provided by Future Technology Devices
 * International Limited ("FTDI") subject to the licence terms set out
 * http://www.ftdichip.com/FTSourceCodeLicenceTerms.htm ("the Licence Terms").
 * You must read the Licence Terms before downloading or using the Software.
 * By installing or using the Software you agree to the Licence Terms. If you
 * do not agree to the Licence Terms then do not download or use the Software.
 *
 * Without prejudice to the Licence Terms, here is a summary of some of the key
 * terms of the Licence Terms (and in the event of any conflict between this
 * summary and the Licence Terms then the text of the Licence Terms will
 * prevail).
 *
 * The Software is provided "as is".
 * There are no warranties (or similar) in relation to the quality of the
 * Software. You use it at your own risk.
 * The Software should not be used in, or for, any medical device, system or
 * appliance. There are exclusions of FTDI liability for certain types of loss
 * such as: special loss or damage; incidental loss or damage; indirect or
 * consequential loss or damage; loss of income; loss of business; loss of
 * profits; loss of revenue; loss of contracts; business interruption; loss of
 * the use of money or anticipated savings; loss of information; loss of
 * opportunity; loss of goodwill or reputation; and/or loss of, damage to or
 * corruption of data.
 * There is a monetary cap on FTDI's liability.
 * The Software may have subsequently been amended by another user and then
 * distributed by that other user ("Adapted Software").  If so that user may
 * have additional licence terms that apply to those amendments. However, FTDI
 * has no liability in relation to those amendments.
 * ============================================================================
 */

#ifndef __FT51_DIO_REGISTERS_H__
#define __FT51_DIO_REGISTERS_H__

//------------------------------------------------------------------------------
// Register 26 (0x1A) DIGITAL_CONTROL_GPIO_0
#define DIGITAL_CONTROL_GPIO_0             0x1A

// Register 26 Bit Definitions
#define BIT_DIO_0_DRIVE_STRENGTH_0            0                                 // DIO Pad 0 Drive Strength Control. 0=0.25x. 1=0.5x. 2=0.75x. 3=1.0x.
#define MASK_DIO_0_DRIVE_STRENGTH_0           (0x1 << BIT_DIO_0_DRIVE_STRENGTH_0)
#define BIT_DIO_0_DRIVE_STRENGTH_1            1                                 // DIO Pad 0 Drive Strength Control. 0=0.25x. 1=0.5x. 2=0.75x. 3=1.0x.
#define MASK_DIO_0_DRIVE_STRENGTH_1           (0x1 << BIT_DIO_0_DRIVE_STRENGTH_1)
#define MASK_DIO_0_DRIVE_STRENGTH             (0x3 << BIT_DIO_0_DRIVE_STRENGTH_0)
#define BIT_DIO_0_PUENA                       2                                 // DIO Pad 0 Pull Up Enable. 0 - Disabled. 1 - Enabled.
#define MASK_DIO_0_PUENA                      (0x1 << BIT_DIO_0_PUENA)
#define BIT_DIO_0_PDENA                       3                                 // DIO Pad 0 Pull Down Enable. 0 - Disabled. 1 - Enabled.
#define MASK_DIO_0_PDENA                      (0x1 << BIT_DIO_0_PDENA)
#define BIT_DIO_0_SMT                         4                                 // DIO Pad 0 Schmitt Enable. 0 - Disabled. 1 - Enabled.
#define MASK_DIO_0_SMT                        (0x1 << BIT_DIO_0_SMT)
#define BIT_DIO_0_SR                          5                                 // DIO Pad 0 Slew Rate Control. 0 - Normal. 1 - Slow.
#define MASK_DIO_0_SR                         (0x1 << BIT_DIO_0_SR)

//------------------------------------------------------------------------------
// Register 27 (0x1B) DIGITAL_CONTROL_GPIO_1
#define DIGITAL_CONTROL_GPIO_1             0x1B

// Register 27 Bit Definitions
#define BIT_DIO_1_DRIVE_STRENGTH_0            0                                 // DIO Pad 1 Drive Strength Control. 0=0.25x. 1=0.5x. 2=0.75x. 3=1.0x.
#define MASK_DIO_1_DRIVE_STRENGTH_0           (0x1 << BIT_DIO_1_DRIVE_STRENGTH_0)
#define BIT_DIO_1_DRIVE_STRENGTH_1            1                                 // DIO Pad 1 Drive Strength Control. 0=0.25x. 1=0.5x. 2=0.75x. 3=1.0x.
#define MASK_DIO_1_DRIVE_STRENGTH_1           (0x1 << BIT_DIO_1_DRIVE_STRENGTH_1)
#define MASK_DIO_1_DRIVE_STRENGTH             (0x3 << BIT_DIO_1_DRIVE_STRENGTH_0)
#define BIT_DIO_1_PUENA                       2                                 // DIO Pad 1 Pull Up Enable. 0 - Disabled. 1 - Enabled.
#define MASK_DIO_1_PUENA                      (0x1 << BIT_DIO_1_PUENA)
#define BIT_DIO_1_PDENA                       3                                 // DIO Pad 1 Pull Down Enable. 0 - Disabled. 1 - Enabled.
#define MASK_DIO_1_PDENA                      (0x1 << BIT_DIO_1_PDENA)
#define BIT_DIO_1_SMT                         4                                 // DIO Pad 1 Schmitt Enable. 0 - Disabled. 1 - Enabled.
#define MASK_DIO_1_SMT                        (0x1 << BIT_DIO_1_SMT)
#define BIT_DIO_1_SR                          5                                 // DIO Pad 1 Slew Rate Control. 0 - Normal. 1 - Slow.
#define MASK_DIO_1_SR                         (0x1 << BIT_DIO_1_SR)

//------------------------------------------------------------------------------
// Register 28 (0x1C) DIGITAL_CONTROL_GPIO_2
#define DIGITAL_CONTROL_GPIO_2             0x1C

// Register 28 Bit Definitions
#define BIT_DIO_2_DRIVE_STRENGTH_0            0                                 // DIO Pad 2 Drive Strength Control. 0=0.25x. 1=0.5x. 2=0.75x. 3=1.0x.
#define MASK_DIO_2_DRIVE_STRENGTH_0           (0x1 << BIT_DIO_2_DRIVE_STRENGTH_0)
#define BIT_DIO_2_DRIVE_STRENGTH_1            1                                 // DIO Pad 2 Drive Strength Control. 0=0.25x. 1=0.5x. 2=0.75x. 3=1.0x.
#define MASK_DIO_2_DRIVE_STRENGTH_1           (0x1 << BIT_DIO_2_DRIVE_STRENGTH_1)
#define MASK_DIO_2_DRIVE_STRENGTH             (0x3 << BIT_DIO_2_DRIVE_STRENGTH_0)
#define BIT_DIO_2_PUENA                       2                                 // DIO Pad 2 Pull Up Enable. 0 - Disabled. 1 - Enabled.
#define MASK_DIO_2_PUENA                      (0x1 << BIT_DIO_2_PUENA)
#define BIT_DIO_2_PDENA                       3                                 // DIO Pad 2 Pull Down Enable. 0 - Disabled. 1 - Enabled.
#define MASK_DIO_2_PDENA                      (0x1 << BIT_DIO_2_PDENA)
#define BIT_DIO_2_SMT                         4                                 // DIO Pad 2 Schmitt Enable. 0 - Disabled. 1 - Enabled.
#define MASK_DIO_2_SMT                        (0x1 << BIT_DIO_2_SMT)
#define BIT_DIO_2_SR                          5                                 // DIO Pad 2 Slew Rate Control. 0 - Normal. 1 - Slow.
#define MASK_DIO_2_SR                         (0x1 << BIT_DIO_2_SR)

//------------------------------------------------------------------------------
// Register 29 (0x1D) DIGITAL_CONTROL_GPIO_3
#define DIGITAL_CONTROL_GPIO_3             0x1D

// Register 29 Bit Definitions
#define BIT_DIO_3_DRIVE_STRENGTH_0            0                                 // DIO Pad 3 Drive Strength Control. 0=0.25x. 1=0.5x. 2=0.75x. 3=1.0x.
#define MASK_DIO_3_DRIVE_STRENGTH_0           (0x1 << BIT_DIO_3_DRIVE_STRENGTH_0)
#define BIT_DIO_3_DRIVE_STRENGTH_1            1                                 // DIO Pad 3 Drive Strength Control. 0=0.25x. 1=0.5x. 2=0.75x. 3=1.0x.
#define MASK_DIO_3_DRIVE_STRENGTH_1           (0x1 << BIT_DIO_3_DRIVE_STRENGTH_1)
#define MASK_DIO_3_DRIVE_STRENGTH             (0x3 << BIT_DIO_3_DRIVE_STRENGTH_0)
#define BIT_DIO_3_PUENA                       2                                 // DIO Pad 3 Pull Up Enable. 0 - Disabled. 1 - Enabled.
#define MASK_DIO_3_PUENA                      (0x1 << BIT_DIO_3_PUENA)
#define BIT_DIO_3_PDENA                       3                                 // DIO Pad 3 Pull Down Enable. 0 - Disabled. 1 - Enabled.
#define MASK_DIO_3_PDENA                      (0x1 << BIT_DIO_3_PDENA)
#define BIT_DIO_3_SMT                         4                                 // DIO Pad 3 Schmitt Enable. 0 - Disabled. 1 - Enabled.
#define MASK_DIO_3_SMT                        (0x1 << BIT_DIO_3_SMT)
#define BIT_DIO_3_SR                          5                                 // DIO Pad 3 Slew Rate Control. 0 - Normal. 1 - Slow.
#define MASK_DIO_3_SR                         (0x1 << BIT_DIO_3_SR)

//------------------------------------------------------------------------------
// Register 30 (0x1E) DIGITAL_CONTROL_GPIO_4
#define DIGITAL_CONTROL_GPIO_4             0x1E

// Register 30 Bit Definitions
#define BIT_DIO_4_DRIVE_STRENGTH_0            0                                 // DIO Pad 4 Drive Strength Control. 0=0.25x. 1=0.5x. 2=0.75x. 3=1.0x.
#define MASK_DIO_4_DRIVE_STRENGTH_0           (0x1 << BIT_DIO_4_DRIVE_STRENGTH_0)
#define BIT_DIO_4_DRIVE_STRENGTH_1            1                                 // DIO Pad 4 Drive Strength Control. 0=0.25x. 1=0.5x. 2=0.75x. 3=1.0x.
#define MASK_DIO_4_DRIVE_STRENGTH_1           (0x1 << BIT_DIO_4_DRIVE_STRENGTH_1)
#define MASK_DIO_4_DRIVE_STRENGTH             (0x3 << BIT_DIO_4_DRIVE_STRENGTH_0)
#define BIT_DIO_4_PUENA                       2                                 // DIO Pad 4 Pull Up Enable. 0 - Disabled. 1 - Enabled.
#define MASK_DIO_4_PUENA                      (0x1 << BIT_DIO_4_PUENA)
#define BIT_DIO_4_PDENA                       3                                 // DIO Pad 4 Pull Down Enable. 0 - Disabled. 1 - Enabled.
#define MASK_DIO_4_PDENA                      (0x1 << BIT_DIO_4_PDENA)
#define BIT_DIO_4_SMT                         4                                 // DIO Pad 4 Schmitt Enable. 0 - Disabled. 1 - Enabled.
#define MASK_DIO_4_SMT                        (0x1 << BIT_DIO_4_SMT)
#define BIT_DIO_4_SR                          5                                 // DIO Pad 4 Slew Rate Control. 0 - Normal. 1 - Slow.
#define MASK_DIO_4_SR                         (0x1 << BIT_DIO_4_SR)

//------------------------------------------------------------------------------
// Register 31 (0x1F) DIGITAL_CONTROL_GPIO_5
#define DIGITAL_CONTROL_GPIO_5             0x1F

// Register 31 Bit Definitions
#define BIT_DIO_5_DRIVE_STRENGTH_0            0                                 // DIO Pad 5 Drive Strength Control. 0=0.25x. 1=0.5x. 2=0.75x. 3=1.0x.
#define MASK_DIO_5_DRIVE_STRENGTH_0           (0x1 << BIT_DIO_5_DRIVE_STRENGTH_0)
#define BIT_DIO_5_DRIVE_STRENGTH_1            1                                 // DIO Pad 5 Drive Strength Control. 0=0.25x. 1=0.5x. 2=0.75x. 3=1.0x.
#define MASK_DIO_5_DRIVE_STRENGTH_1           (0x1 << BIT_DIO_5_DRIVE_STRENGTH_1)
#define MASK_DIO_5_DRIVE_STRENGTH             (0x3 << BIT_DIO_5_DRIVE_STRENGTH_0)
#define BIT_DIO_5_PUENA                       2                                 // DIO Pad 5 Pull Up Enable. 0 - Disabled. 1 - Enabled.
#define MASK_DIO_5_PUENA                      (0x1 << BIT_DIO_5_PUENA)
#define BIT_DIO_5_PDENA                       3                                 // DIO Pad 5 Pull Down Enable. 0 - Disabled. 1 - Enabled.
#define MASK_DIO_5_PDENA                      (0x1 << BIT_DIO_5_PDENA)
#define BIT_DIO_5_SMT                         4                                 // DIO Pad 5 Schmitt Enable. 0 - Disabled. 1 - Enabled.
#define MASK_DIO_5_SMT                        (0x1 << BIT_DIO_5_SMT)
#define BIT_DIO_5_SR                          5                                 // DIO Pad 5 Slew Rate Control. 0 - Normal. 1 - Slow.
#define MASK_DIO_5_SR                         (0x1 << BIT_DIO_5_SR)

//------------------------------------------------------------------------------
// Register 32 (0x20) DIGITAL_CONTROL_GPIO_6
#define DIGITAL_CONTROL_GPIO_6             0x20

// Register 32 Bit Definitions
#define BIT_DIO_6_DRIVE_STRENGTH_0            0                                 // DIO Pad 6 Drive Strength Control. 0=0.25x. 1=0.5x. 2=0.75x. 3=1.0x.
#define MASK_DIO_6_DRIVE_STRENGTH_0           (0x1 << BIT_DIO_6_DRIVE_STRENGTH_0)
#define BIT_DIO_6_DRIVE_STRENGTH_1            1                                 // DIO Pad 6 Drive Strength Control. 0=0.25x. 1=0.5x. 2=0.75x. 3=1.0x.
#define MASK_DIO_6_DRIVE_STRENGTH_1           (0x1 << BIT_DIO_6_DRIVE_STRENGTH_1)
#define MASK_DIO_6_DRIVE_STRENGTH             (0x3 << BIT_DIO_6_DRIVE_STRENGTH_0)
#define BIT_DIO_6_PUENA                       2                                 // DIO Pad 6 Pull Up Enable. 0 - Disabled. 1 - Enabled.
#define MASK_DIO_6_PUENA                      (0x1 << BIT_DIO_6_PUENA)
#define BIT_DIO_6_PDENA                       3                                 // DIO Pad 6 Pull Down Enable. 0 - Disabled. 1 - Enabled.
#define MASK_DIO_6_PDENA                      (0x1 << BIT_DIO_6_PDENA)
#define BIT_DIO_6_SMT                         4                                 // DIO Pad 6 Schmitt Enable. 0 - Disabled. 1 - Enabled.
#define MASK_DIO_6_SMT                        (0x1 << BIT_DIO_6_SMT)
#define BIT_DIO_6_SR                          5                                 // DIO Pad 6 Slew Rate Control. 0 - Normal. 1 - Slow.
#define MASK_DIO_6_SR                         (0x1 << BIT_DIO_6_SR)

//------------------------------------------------------------------------------
// Register 33 (0x21) DIGITAL_CONTROL_GPIO_7
#define DIGITAL_CONTROL_GPIO_7             0x21

// Register 33 Bit Definitions
#define BIT_DIO_7_DRIVE_STRENGTH_0            0                                 // DIO Pad 7 Drive Strength Control. 0=0.25x. 1=0.5x. 2=0.75x. 3=1.0x.
#define MASK_DIO_7_DRIVE_STRENGTH_0           (0x1 << BIT_DIO_7_DRIVE_STRENGTH_0)
#define BIT_DIO_7_DRIVE_STRENGTH_1            1                                 // DIO Pad 7 Drive Strength Control. 0=0.25x. 1=0.5x. 2=0.75x. 3=1.0x.
#define MASK_DIO_7_DRIVE_STRENGTH_1           (0x1 << BIT_DIO_7_DRIVE_STRENGTH_1)
#define MASK_DIO_7_DRIVE_STRENGTH             (0x3 << BIT_DIO_7_DRIVE_STRENGTH_0)
#define BIT_DIO_7_PUENA                       2                                 // DIO Pad 7 Pull Up Enable. 0 - Disabled. 1 - Enabled.
#define MASK_DIO_7_PUENA                      (0x1 << BIT_DIO_7_PUENA)
#define BIT_DIO_7_PDENA                       3                                 // DIO Pad 7 Pull Down Enable. 0 - Disabled. 1 - Enabled.
#define MASK_DIO_7_PDENA                      (0x1 << BIT_DIO_7_PDENA)
#define BIT_DIO_7_SMT                         4                                 // DIO Pad 7 Schmitt Enable. 0 - Disabled. 1 - Enabled.
#define MASK_DIO_7_SMT                        (0x1 << BIT_DIO_7_SMT)
#define BIT_DIO_7_SR                          5                                 // DIO Pad 7 Slew Rate Control. 0 - Normal. 1 - Slow.
#define MASK_DIO_7_SR                         (0x1 << BIT_DIO_7_SR)

//------------------------------------------------------------------------------
// Register 34 (0x22) DIGITAL_CONTROL_GPIO_8
#define DIGITAL_CONTROL_GPIO_8             0x22

// Register 34 Bit Definitions
#define BIT_DIO_8_DRIVE_STRENGTH_0            0                                 // DIO Pad 8 Drive Strength Control. 0=0.25x. 1=0.5x. 2=0.75x. 3=1.0x.
#define MASK_DIO_8_DRIVE_STRENGTH_0           (0x1 << BIT_DIO_8_DRIVE_STRENGTH_0)
#define BIT_DIO_8_DRIVE_STRENGTH_1            1                                 // DIO Pad 8 Drive Strength Control. 0=0.25x. 1=0.5x. 2=0.75x. 3=1.0x.
#define MASK_DIO_8_DRIVE_STRENGTH_1           (0x1 << BIT_DIO_8_DRIVE_STRENGTH_1)
#define MASK_DIO_8_DRIVE_STRENGTH             (0x3 << BIT_DIO_8_DRIVE_STRENGTH_0)
#define BIT_DIO_8_PUENA                       2                                 // DIO Pad 8 Pull Up Enable. 0 - Disabled. 1 - Enabled.
#define MASK_DIO_8_PUENA                      (0x1 << BIT_DIO_8_PUENA)
#define BIT_DIO_8_PDENA                       3                                 // DIO Pad 8 Pull Down Enable. 0 - Disabled. 1 - Enabled.
#define MASK_DIO_8_PDENA                      (0x1 << BIT_DIO_8_PDENA)
#define BIT_DIO_8_SMT                         4                                 // DIO Pad 8 Schmitt Enable. 0 - Disabled. 1 - Enabled.
#define MASK_DIO_8_SMT                        (0x1 << BIT_DIO_8_SMT)
#define BIT_DIO_8_SR                          5                                 // DIO Pad 8 Slew Rate Control. 0 - Normal. 1 - Slow.
#define MASK_DIO_8_SR                         (0x1 << BIT_DIO_8_SR)

//------------------------------------------------------------------------------
// Register 35 (0x23) DIGITAL_CONTROL_GPIO_9
#define DIGITAL_CONTROL_GPIO_9             0x23

// Register 35 Bit Definitions
#define BIT_DIO_9_DRIVE_STRENGTH_0            0                                 // DIO Pad 9 Drive Strength Control. 0=0.25x. 1=0.5x. 2=0.75x. 3=1.0x.
#define MASK_DIO_9_DRIVE_STRENGTH_0           (0x1 << BIT_DIO_9_DRIVE_STRENGTH_0)
#define BIT_DIO_9_DRIVE_STRENGTH_1            1                                 // DIO Pad 9 Drive Strength Control. 0=0.25x. 1=0.5x. 2=0.75x. 3=1.0x.
#define MASK_DIO_9_DRIVE_STRENGTH_1           (0x1 << BIT_DIO_9_DRIVE_STRENGTH_1)
#define MASK_DIO_9_DRIVE_STRENGTH             (0x3 << BIT_DIO_9_DRIVE_STRENGTH_0)
#define BIT_DIO_9_PUENA                       2                                 // DIO Pad 9 Pull Up Enable. 0 - Disabled. 1 - Enabled.
#define MASK_DIO_9_PUENA                      (0x1 << BIT_DIO_9_PUENA)
#define BIT_DIO_9_PDENA                       3                                 // DIO Pad 9 Pull Down Enable. 0 - Disabled. 1 - Enabled.
#define MASK_DIO_9_PDENA                      (0x1 << BIT_DIO_9_PDENA)
#define BIT_DIO_9_SMT                         4                                 // DIO Pad 9 Schmitt Enable. 0 - Disabled. 1 - Enabled.
#define MASK_DIO_9_SMT                        (0x1 << BIT_DIO_9_SMT)
#define BIT_DIO_9_SR                          5                                 // DIO Pad 9 Slew Rate Control. 0 - Normal. 1 - Slow.
#define MASK_DIO_9_SR                         (0x1 << BIT_DIO_9_SR)

//------------------------------------------------------------------------------
// Register 36 (0x24) DIGITAL_CONTROL_GPIO_10
#define DIGITAL_CONTROL_GPIO_10            0x24

// Register 36 Bit Definitions
#define BIT_DIO_10_DRIVE_STRENGTH_0           0                                 // DIO Pad 10 Drive Strength Control. 0=0.25x. 1=0.5x. 2=0.75x. 3=1.0x.
#define MASK_DIO_10_DRIVE_STRENGTH_0          (0x1 << BIT_DIO_10_DRIVE_STRENGTH_0)
#define BIT_DIO_10_DRIVE_STRENGTH_1           1                                 // DIO Pad 10 Drive Strength Control. 0=0.25x. 1=0.5x. 2=0.75x. 3=1.0x.
#define MASK_DIO_10_DRIVE_STRENGTH_1          (0x1 << BIT_DIO_10_DRIVE_STRENGTH_1)
#define MASK_DIO_10_DRIVE_STRENGTH            (0x3 << BIT_DIO_10_DRIVE_STRENGTH_0)
#define BIT_DIO_10_PUENA                      2                                 // DIO Pad 10 Pull Up Enable. 0 - Disabled. 1 - Enabled.
#define MASK_DIO_10_PUENA                     (0x1 << BIT_DIO_10_PUENA)
#define BIT_DIO_10_PDENA                      3                                 // DIO Pad 10 Pull Down Enable. 0 - Disabled. 1 - Enabled.
#define MASK_DIO_10_PDENA                     (0x1 << BIT_DIO_10_PDENA)
#define BIT_DIO_10_SMT                        4                                 // DIO Pad 10 Schmitt Enable. 0 - Disabled. 1 - Enabled.
#define MASK_DIO_10_SMT                       (0x1 << BIT_DIO_10_SMT)
#define BIT_DIO_10_SR                         5                                 // DIO Pad 10 Slew Rate Control. 0 - Normal. 1 - Slow.
#define MASK_DIO_10_SR                        (0x1 << BIT_DIO_10_SR)

//------------------------------------------------------------------------------
// Register 37 (0x25) DIGITAL_CONTROL_GPIO_11
#define DIGITAL_CONTROL_GPIO_11            0x25

// Register 37 Bit Definitions
#define BIT_DIO_11_DRIVE_STRENGTH_0           0                                 // DIO Pad 11 Drive Strength Control. 0=0.25x. 1=0.5x. 2=0.75x. 3=1.0x.
#define MASK_DIO_11_DRIVE_STRENGTH_0          (0x1 << BIT_DIO_11_DRIVE_STRENGTH_0)
#define BIT_DIO_11_DRIVE_STRENGTH_1           1                                 // DIO Pad 11 Drive Strength Control. 0=0.25x. 1=0.5x. 2=0.75x. 3=1.0x.
#define MASK_DIO_11_DRIVE_STRENGTH_1          (0x1 << BIT_DIO_11_DRIVE_STRENGTH_1)
#define MASK_DIO_11_DRIVE_STRENGTH            (0x3 << BIT_DIO_11_DRIVE_STRENGTH_0)
#define BIT_DIO_11_PUENA                      2                                 // DIO Pad 11 Pull Up Enable. 0 - Disabled. 1 - Enabled.
#define MASK_DIO_11_PUENA                     (0x1 << BIT_DIO_11_PUENA)
#define BIT_DIO_11_PDENA                      3                                 // DIO Pad 11 Pull Down Enable. 0 - Disabled. 1 - Enabled.
#define MASK_DIO_11_PDENA                     (0x1 << BIT_DIO_11_PDENA)
#define BIT_DIO_11_SMT                        4                                 // DIO Pad 11 Schmitt Enable. 0 - Disabled. 1 - Enabled.
#define MASK_DIO_11_SMT                       (0x1 << BIT_DIO_11_SMT)
#define BIT_DIO_11_SR                         5                                 // DIO Pad 11 Slew Rate Control. 0 - Normal. 1 - Slow.
#define MASK_DIO_11_SR                        (0x1 << BIT_DIO_11_SR)

//------------------------------------------------------------------------------
// Register 38 (0x26) DIGITAL_CONTROL_GPIO_12
#define DIGITAL_CONTROL_GPIO_12            0x26

// Register 38 Bit Definitions
#define BIT_DIO_12_DRIVE_STRENGTH_0           0                                 // DIO Pad 12 Drive Strength Control. 0=0.25x. 1=0.5x. 2=0.75x. 3=1.0x.
#define MASK_DIO_12_DRIVE_STRENGTH_0          (0x1 << BIT_DIO_12_DRIVE_STRENGTH_0)
#define BIT_DIO_12_DRIVE_STRENGTH_1           1                                 // DIO Pad 12 Drive Strength Control. 0=0.25x. 1=0.5x. 2=0.75x. 3=1.0x.
#define MASK_DIO_12_DRIVE_STRENGTH_1          (0x1 << BIT_DIO_12_DRIVE_STRENGTH_1)
#define MASK_DIO_12_DRIVE_STRENGTH            (0x3 << BIT_DIO_12_DRIVE_STRENGTH_0)
#define BIT_DIO_12_PUENA                      2                                 // DIO Pad 12 Pull Up Enable. 0 - Disabled. 1 - Enabled.
#define MASK_DIO_12_PUENA                     (0x1 << BIT_DIO_12_PUENA)
#define BIT_DIO_12_PDENA                      3                                 // DIO Pad 12 Pull Down Enable. 0 - Disabled. 1 - Enabled.
#define MASK_DIO_12_PDENA                     (0x1 << BIT_DIO_12_PDENA)
#define BIT_DIO_12_SMT                        4                                 // DIO Pad 12 Schmitt Enable. 0 - Disabled. 1 - Enabled.
#define MASK_DIO_12_SMT                       (0x1 << BIT_DIO_12_SMT)
#define BIT_DIO_12_SR                         5                                 // DIO Pad 12 Slew Rate Control. 0 - Normal. 1 - Slow.
#define MASK_DIO_12_SR                        (0x1 << BIT_DIO_12_SR)

//------------------------------------------------------------------------------
// Register 39 (0x27) DIGITAL_CONTROL_GPIO_13
#define DIGITAL_CONTROL_GPIO_13            0x27

// Register 39 Bit Definitions
#define BIT_DIO_13_DRIVE_STRENGTH_0           0                                 // DIO Pad 13 Drive Strength Control. 0=0.25x. 1=0.5x. 2=0.75x. 3=1.0x.
#define MASK_DIO_13_DRIVE_STRENGTH_0          (0x1 << BIT_DIO_13_DRIVE_STRENGTH_0)
#define BIT_DIO_13_DRIVE_STRENGTH_1           1                                 // DIO Pad 13 Drive Strength Control. 0=0.25x. 1=0.5x. 2=0.75x. 3=1.0x.
#define MASK_DIO_13_DRIVE_STRENGTH_1          (0x1 << BIT_DIO_13_DRIVE_STRENGTH_1)
#define MASK_DIO_13_DRIVE_STRENGTH            (0x3 << BIT_DIO_13_DRIVE_STRENGTH_0)
#define BIT_DIO_13_PUENA                      2                                 // DIO Pad 13 Pull Up Enable. 0 - Disabled. 1 - Enabled.
#define MASK_DIO_13_PUENA                     (0x1 << BIT_DIO_13_PUENA)
#define BIT_DIO_13_PDENA                      3                                 // DIO Pad 13 Pull Down Enable. 0 - Disabled. 1 - Enabled.
#define MASK_DIO_13_PDENA                     (0x1 << BIT_DIO_13_PDENA)
#define BIT_DIO_13_SMT                        4                                 // DIO Pad 13 Schmitt Enable. 0 - Disabled. 1 - Enabled.
#define MASK_DIO_13_SMT                       (0x1 << BIT_DIO_13_SMT)
#define BIT_DIO_13_SR                         5                                 // DIO Pad 13 Slew Rate Control. 0 - Normal. 1 - Slow.
#define MASK_DIO_13_SR                        (0x1 << BIT_DIO_13_SR)

//------------------------------------------------------------------------------
// Register 40 (0x28) DIGITAL_CONTROL_GPIO_14
#define DIGITAL_CONTROL_GPIO_14            0x28

// Register 40 Bit Definitions
#define BIT_DIO_14_DRIVE_STRENGTH_0           0                                 // DIO Pad 14 Drive Strength Control. 0=0.25x. 1=0.5x. 2=0.75x. 3=1.0x.
#define MASK_DIO_14_DRIVE_STRENGTH_0          (0x1 << BIT_DIO_14_DRIVE_STRENGTH_0)
#define BIT_DIO_14_DRIVE_STRENGTH_1           1                                 // DIO Pad 14 Drive Strength Control. 0=0.25x. 1=0.5x. 2=0.75x. 3=1.0x.
#define MASK_DIO_14_DRIVE_STRENGTH_1          (0x1 << BIT_DIO_14_DRIVE_STRENGTH_1)
#define MASK_DIO_14_DRIVE_STRENGTH            (0x3 << BIT_DIO_14_DRIVE_STRENGTH_0)
#define BIT_DIO_14_PUENA                      2                                 // DIO Pad 14 Pull Up Enable. 0 - Disabled. 1 - Enabled.
#define MASK_DIO_14_PUENA                     (0x1 << BIT_DIO_14_PUENA)
#define BIT_DIO_14_PDENA                      3                                 // DIO Pad 14 Pull Down Enable. 0 - Disabled. 1 - Enabled.
#define MASK_DIO_14_PDENA                     (0x1 << BIT_DIO_14_PDENA)
#define BIT_DIO_14_SMT                        4                                 // DIO Pad 14 Schmitt Enable. 0 - Disabled. 1 - Enabled.
#define MASK_DIO_14_SMT                       (0x1 << BIT_DIO_14_SMT)
#define BIT_DIO_14_SR                         5                                 // DIO Pad 14 Slew Rate Control. 0 - Normal. 1 - Slow.
#define MASK_DIO_14_SR                        (0x1 << BIT_DIO_14_SR)

//------------------------------------------------------------------------------
// Register 41 (0x29) DIGITAL_CONTROL_GPIO_15
#define DIGITAL_CONTROL_GPIO_15            0x29

// Register 41 Bit Definitions
#define BIT_DIO_15_DRIVE_STRENGTH_0           0                                 // DIO Pad 15 Drive Strength Control. 0=0.25x. 1=0.5x. 2=0.75x. 3=1.0x.
#define MASK_DIO_15_DRIVE_STRENGTH_0          (0x1 << BIT_DIO_15_DRIVE_STRENGTH_0)
#define BIT_DIO_15_DRIVE_STRENGTH_1           1                                 // DIO Pad 15 Drive Strength Control. 0=0.25x. 1=0.5x. 2=0.75x. 3=1.0x.
#define MASK_DIO_15_DRIVE_STRENGTH_1          (0x1 << BIT_DIO_15_DRIVE_STRENGTH_1)
#define MASK_DIO_15_DRIVE_STRENGTH            (0x3 << BIT_DIO_15_DRIVE_STRENGTH_0)
#define BIT_DIO_15_PUENA                      2                                 // DIO Pad 15 Pull Up Enable. 0 - Disabled. 1 - Enabled.
#define MASK_DIO_15_PUENA                     (0x1 << BIT_DIO_15_PUENA)
#define BIT_DIO_15_PDENA                      3                                 // DIO Pad 15 Pull Down Enable. 0 - Disabled. 1 - Enabled.
#define MASK_DIO_15_PDENA                     (0x1 << BIT_DIO_15_PDENA)
#define BIT_DIO_15_SMT                        4                                 // DIO Pad 15 Schmitt Enable. 0 - Disabled. 1 - Enabled.
#define MASK_DIO_15_SMT                       (0x1 << BIT_DIO_15_SMT)
#define BIT_DIO_15_SR                         5                                 // DIO Pad 15 Slew Rate Control. 0 - Normal. 1 - Slow.
#define MASK_DIO_15_SR                        (0x1 << BIT_DIO_15_SR)

#endif // __FT51_DIO_REGISTERS_H__